==> codelogic_mcp_server-0.3.1.tar.gz: codelogic_mcp_server-0.3.1/CONTRIBUTING.md <==
# Contributing to codelogic-mcp-server

Thank you for your interest in contributing to codelogic-mcp-server! This document provides guidelines and instructions for contributing.

## Code of Conduct

Please read and follow our [Code of Conduct](CODE_OF_CONDUCT.md).

## How to Contribute

### Reporting Bugs

1. Check if the bug has already been reported in our [Issues](https://github.com/yourusername/codelogic-mcp-server/issues)
2. If not, create a new issue using the bug report template
3. Include detailed steps to reproduce the bug
4. Include your environment details (OS, Python version, etc.)

### Suggesting Features

1. Check if the feature has already been suggested in our [Issues](https://github.com/yourusername/codelogic-mcp-server/issues)
2. If not, create a new issue using the feature request template
3. Clearly describe the feature and its benefits

### Pull Requests

1. Fork the repository
2. Create a new branch for your changes
3. Make your changes and commit them with clear commit messages
4. Write tests for your changes
5. Run all tests and ensure they pass
6. Submit a pull request with a description of your changes

## Development Setup

1. Clone the repository
2. Install dependencies: `uv venv && uv pip install -e .`
3. Run tests: `pytest`

## Coding Standards

- Follow PEP 8 guidelines
- Include docstrings for all classes and functions
- Write unit tests for new functionality

## License

By contributing to this project, you agree that your contributions will be licensed under the project's [Mozilla Public License 2.0](LICENSE).

==> codelogic_mcp_server-1.0.0.tar.gz: codelogic_mcp_server-1.0.0/CONTRIBUTING.md <==
# Contributing to codelogic-mcp-server

Thank you for your interest in contributing to codelogic-mcp-server! This document provides guidelines and instructions for contributing.

## Code of Conduct

Please read and follow our [Code of Conduct](CODE_OF_CONDUCT.md).

## How to Contribute

### Reporting Bugs

1. Check if the bug has already been reported in our [Issues](https://github.com/CodeLogicIncEngineering/codelogic-mcp-server/issues)
2. If not, create a new issue using the bug report template
3. Include detailed steps to reproduce the bug
4. Include your environment details (OS, Python version, etc.)

### Suggesting Features

1. Check if the feature has already been suggested in our [Issues](https://github.com/CodeLogicIncEngineering/codelogic-mcp-server/issues)
2. If not, create a new issue using the feature request template
3. Clearly describe the feature and its benefits

### Pull Requests

1. Fork the repository
2. Create a new branch for your changes
3. Make your changes and commit them with clear commit messages
4. Write tests for your changes
5. Run all tests and ensure they pass
6. Submit a pull request with a description of your changes

## Development Setup

1. Clone the repository
2. Install dependencies: `uv venv && uv pip install -e .`
3. Run unit tests: `python -m unittest test/unit*`

## Coding Standards

- Follow PEP 8 guidelines
- Include docstrings for all classes and functions
- Write unit tests for new functionality

## License

By contributing to this project, you agree that your contributions will be licensed under the project's [Mozilla Public License 2.0](LICENSE).
